#!/bin/bash

__COLOR(){

	local CUSTOM_SETTINGS="$3"
	local END="\033[0m"
		if [ "$1" ]; then
			case "$2" in
				red)    C="\033[0;31m" ;;
				green)  C="\033[0;32m" ;;
				white)  C="\033[1m" ;;
				cyan)   C="\033[36m" ;;
				yellow) C="\033[0;33m" ;;
				red2)   C="\033[37;1;41m" ;;
				line)   C="\033[4m" ;;
				white2) C="\033[7m" ;;
			esac
			echo -e${CUSTOM_SETTINGS} "${C}${1}${END}"
		fi

}

__INSTALLING_COMPONENTS(){

	local KERNEL_PACK1='kernel-image-9999.deb'
	local KERNEL_PACK2='kernel-image-atom-9999.deb'

	__COLOR "Installing additional components... " "white" "n"
	dpkg -i /$KERNEL_PACK1 &> /dev/null
	dpkg -i /$KERNEL_PACK2 &> /dev/null

	rm -rf /$KERNEL_PACK1
	rm -rf /$KERNEL_PACK2

	# Doing LDAP reset (for change pbxSerial)
	/usr/sbin/ldap_reset reset &> /dev/null

	# Doing initialize cticonnectdb
	/usr/sbin/init_cticonnectdb

	# Doing initialize wmsdb
	/usr/sbin/init_wmsdb
	__COLOR "Done." "white"
}

__FIXES(){

	__COLOR "Applying fixes... " "white" "n"
	# fix mtab
	[ ! -L "/etc/mtab" ] && rm -f /etc/mtab && ln -s /proc/mounts /etc/mtab

	# add identity
	mkdir -p  /usr/ide/hda
	cat << 'EOF' > /usr/ide/hda/identify
0040 1041 0000 0010 0000 0200 003f 0000
0000 0000 5642 3461 3632 3437 3832 2d66
3537 3232 3836 6220 0003 0200 0000 312e
3020 2020 2020 5642 4f58 2048 4152 4444
4953 4b20 2020 2020 2020 2020 2020 2020
2020 2020 2020 2020 2020 2020 2020 8080
EOF

	echo "/dev/xvda100 /tmp/identify ext2 rw,noatime,nodiratime,sync 0 0" > /etc/fstab
	chmod 644 /etc/fstab

	# fix it after decision about /mnt storage
	[ -f "/etc/monit/mntmem.conf" ] && mv /etc/monit/mntmem.conf /etc/monit/mntmem.conf.not_use

	# fix ssh port change it to 2222
	sed -i  "s/^Port 22$/Port 2222/" /etc/ssh/sshd_config

	# clear openvpn config
	rm -rf /etc/openvpn/*

	# fix FS2
	if [ ! -f "/rw2/etc/sf2" ]; then
		touch /rw2/etc/sf2
		chown wms:wms /rw2/etc/sf2
	else
		chown wms:wms /rw2/etc/sf2
	fi
	__COLOR "Done." "white"

}

__PREPARING_DIRECTORIES(){

	# Creare TMPFS
	__COLOR "Create tmpfs... " "white" "n"
	/etc/init.d/tmpfs start &> /dev/null
	__COLOR "Done." "white"

	# update hostname
	__COLOR "Changing hostname... " "white" "n"
	echo "$(hostname)" > /etc/hostname
	/etc/network/if-up.d/hosts update
	__COLOR "Done." "white"

	__COLOR "Mount additional directories... " "white" "n"
	sudo mkdir -p /mnt
	sudo mkdir -p /mnt/cticonnect
	sudo mkdir -p /mnt/backups
	sudo mkdir -p /mnt/faxes
	sudo mkdir -p /mnt/cdr
	sudo mkdir -p /mnt/cdrcsv
	/etc/init.d/slapd start &> /dev/null
	/etc/init.d/callweaver start &> /dev/null
	sleep 10
	/usr/sbin/wmsmount &> /dev/null

	## fix for mount on VM systems
	MOUNT_POINTS="
	/dev/shm/var/spool/callweaver/monitor
	/dev/shm/var/spool/callweaver/voicemail
	/mnt/cticonnect
	/mnt/faxes
	/mnt/cdr
	/mnt/cdrcsv
	/mnt/backups
	"

	for MP in $MOUNT_POINTS; do
		if [ ! "$(grep "$MP" /etc/mtab)" ]; then
			mount --bind /media $MP
			__COLOR "mount manually: $MP" "red"
		fi
	done

	sudo chown wms:wms -R /mnt/
	sudo chown wms:wms -R /dev/shm/var/spool/callweaver/
	sudo chown admin:admin -R /home/admin/
	__COLOR "Done." "white"

}

__STARTING_SERVICES(){

	__COLOR "Start main services... " "white" "n"
	/var/www/upgrade/upgrade_stage2.php &> /dev/null
	/etc/rc.local

	# Start main services
	/etc/init.d/rsyslog start &> /dev/null
	/etc/init.d/ssh restart &> /dev/null
	/etc/init.d/shellinabox start &> /dev/null
	/etc/init.d/slapd restart &> /dev/null
	/etc/init.d/wildix-con_client start &> /dev/null
	/etc/init.d/wildix-con_server start &> /dev/null
	/etc/init.d/kamailio start &> /dev/null
	/etc/init.d/callweaver start &> /dev/null
	timeout 300 /usr/sbin/callweaver -rx 'core waitfullybooted' &> /dev/null
	/usr/sbin/callweaver -rx "license reload" &> /dev/null
	[ -f "/usr/sbin/update_kamailio_cfg.sh" ] && /usr/sbin/update_kamailio_cfg.sh localnets &> /dev/null
	[ -f "/usr/sbin/restart_rtpengine_with_delay" ] && /usr/sbin/restart_rtpengine_with_delay &> /dev/null
	/etc/init.d/cron restart &> /dev/null
	/etc/init.d/lighttpd start &> /dev/null
	/etc/init.d/monit start &> /dev/null
	/usr/sbin/wms_set_domain &> /dev/null
	/usr/sbin/sync_all_devices &
	/etc/rc2.d/S99ssl_certificate_renewal start &> /dev/null
	__COLOR "Done." "white"

}

case "$1" in
	install)
		__FIXES
		__PREPARING_DIRECTORIES
		__INSTALLING_COMPONENTS
		__STARTING_SERVICES
	;;
	*)
		__PREPARING_DIRECTORIES
		__STARTING_SERVICES
	;;
esac