/* SecuritySettings module */
(function universalModuleDefinition(root, factory) {
    if (typeof exports === 'object') {
        // CommonJS
        module.exports = factory(require('jquery'));
    } else if (typeof define === 'function' && define.amd) {
        // AMD
        define(['jquery'], factory);
    } else {
        // Browser
        root.SecuritySettings = factory(root.jQuery);
    }
}(this, function ($) {
    'use strict';

    function SecuritySettings(data) {
        this.constructor(data);
    }

    $.extend(SecuritySettings.prototype, {

        constructor: function () {
            // pattern input domain
            this.patternDomain = /^(http|https):\/\/[a-zA-Z\d[\]*.\-:]{2,}$/;
            // form elements
            this.form = $('#security_settings .security_settings_form');
            this.buttonSave = this.form.find('.settings_save');
            this.inputOrigin = this.form.find('#allow_origin');
            this.buttonAddOrigin = this.form.find('button.add_allow_origin');
            this.stackOrigin = this.form.find('.allow_origin_list');

            this.buttonAddOrigin.hide();

            this.form.on('keyup', 'input[name="httpOriginAllow[]"]', $.proxy(this.keyupOrigin, this));
            this.inputOrigin.on('keydown', $.proxy(this.keydownOrigin, this));
            this.buttonAddOrigin.on('click', $.proxy(this.keydownOrigin, this, {preventDefault: function(){}, keyCode: 13}));
            this.form.on('click', 'a.fa-times', $.proxy(this.deleteDomainOrigin, this));
            this.buttonSave.on('click', $.proxy(this.saveForm, this));
        },

        load: function (data) {
            data = data || {};
            this.stackOrigin.empty();
            this.inputOrigin.val('');
            this.buttonAddOrigin.hide();
            if(data.httpOriginAllow) {
                for(var i = data.httpOriginAllow.length; i > 0; i--) {
                    this.addDomainToOrigin(data.httpOriginAllow[i - 1]);
                }
            }
            return this;
        },

        keyupOrigin: function(e) {
            var input = $(e.target);
            var val = input.val();
            var error = false;
            if(val.length == 0 || val.search(this.patternDomain) != -1) {
                input.removeClass('error');
            }else{
                input.addClass('error');
                error = true;
            }

            if(input.attr('id') == 'allow_origin'){
                if(val.length > 0 && error === false) {
                    this.buttonAddOrigin.show();
                }else{
                    this.buttonAddOrigin.hide();
                }
            }
            return true;
        },

        keydownOrigin: function(e) {
            if (e.keyCode === 13) {
                e.preventDefault();
                if(this.inputOrigin.hasClass('error')) {
                    return false;
                }
                // save domain
                var val = this.inputOrigin.val();
                if(val.length > 0) {
                    this.addDomainToOrigin(val);
                    this.inputOrigin.val('');
                    this.buttonAddOrigin.hide();
                }
                return false;
            }
            return true;
        },

        addDomainToOrigin: function(domain) {
            this.stackOrigin.prepend($('<div>')
                .append($('<input>').attr({'name': 'httpOriginAllow[]', 'type': 'text'}).val(domain))
                .append($('<a>').addClass('fa fa-times'))
            );
        },

        deleteDomainOrigin: function(e) {
            var tr = $(e.target).parents('div').eq(0);
            tr.remove();
        },

        saveForm: function () {
            if($('input.error[name="httpOriginAllow[]"]').length > 0) {
                return false;
            }
            ap_showWaitMessage('waitDiv', 1);
            var data = this.form.serialize();
            $.ajax({
                url: 'api/v1/PBX/settings/httpSecurity',
                type: 'POST',
                data: data,
                success: function (response) {
                    if(response.result && 'httpOriginAllow' in response.result) {
                        setError('success', 'Settings saved successfully', 3000);
                        this.load(response.result);
                    }else {
                        setError('error', 'Error ', 5000);
                    }

                    ap_showWaitMessage('waitDiv', 0);
                }.bind(this),
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    console.error(XMLHttpRequest, textStatus, errorThrown);
                    if('responseJSON' in XMLHttpRequest) {
                        setError('error', XMLHttpRequest.responseJSON.reason, 5000);
                    }
                    ap_showWaitMessage('waitDiv', 0);
                }
            });
            return true;
        }
    });
    return SecuritySettings;
}));
